[−][src]Crate actix_mock_helper
actix-mock-helper is a set of helpers for creating mock actors using the Mocker type.
That type of actor can be used to simulate any type of mock you could want, but it's very verbose to interact with.
actix-mock helper is especially useful in the case that you have multiple messages in a sequence that you want to mock
Structs
| MockActorSequence | A mock for a sequence of messages sent to the actor Example: |
Functions
| simple_mock_actor | reduced boilerplate helper for if you have just a single message you expect. |